@@ -28,7 +28,7 @@ public:
 
     static ArchiveMailKernel *self();
 
-    KIdentityManagement::IdentityManager *identityManager() override;
+    KIdentityManagementCore::IdentityManager *identityManager() override;
     MessageComposer::MessageSender *msgSender() override;
 
     Akonadi::EntityMimeTypeFilterModel *collectionModel() const override;
@@ -38,17 +38,17 @@ public:
     Akonadi::ChangeRecorder *folderCollectionMonitor() const override;
     void updateSystemTray() override;
 
-    Q_REQUIRED_RESULT qreal closeToQuotaThreshold() override;
-    Q_REQUIRED_RESULT bool excludeImportantMailFromExpiry() override;
-    Q_REQUIRED_RESULT QStringList customTemplates() override;
-    Q_REQUIRED_RESULT Akonadi::Collection::Id lastSelectedFolder() override;
+    [[nodiscard]] qreal closeToQuotaThreshold() override;
+    [[nodiscard]] bool excludeImportantMailFromExpiry() override;
+    [[nodiscard]] QStringList customTemplates() override;
+    [[nodiscard]] Akonadi::Collection::Id lastSelectedFolder() override;
     void setLastSelectedFolder(Akonadi::Collection::Id col) override;
-    Q_REQUIRED_RESULT bool showPopupAfterDnD() override;
+    [[nodiscard]] bool showPopupAfterDnD() override;
     void expunge(Akonadi::Collection::Id col, bool sync) override;
 
 private:
     Q_DISABLE_COPY(ArchiveMailKernel)
-    KIdentityManagement::IdentityManager *mIdentityManager = nullptr;
+    KIdentityManagementCore::IdentityManager *mIdentityManager = nullptr;
     MailCommon::FolderCollectionMonitor *mFolderCollectionMonitor = nullptr;
     Akonadi::EntityTreeModel *mEntityTreeModel = nullptr;
     Akonadi::EntityMimeTypeFilterModel *mCollectionModel = nullptr;
