@@ -32,6 +32,8 @@ void ArchiveMailInfoTest::shouldHaveDefaultValue()
     QCOMPARE(info.lastDateSaved(), QDate());
     QCOMPARE(info.maximumArchiveCount(), 0);
     QCOMPARE(info.isEnabled(), true);
+    QCOMPARE(info.useRange(), false);
+    QVERIFY(info.range().isEmpty());
 }
 
 void ArchiveMailInfoTest::shouldRestoreFromSettings()
@@ -45,11 +47,13 @@ void ArchiveMailInfoTest::shouldRestoreFromSettings()
     info.setLastDateSaved(QDate::currentDate());
     info.setMaximumArchiveCount(5);
     info.setEnabled(false);
+    info.setUseRange(true);
+    info.setRange({8, 7});
 
-    KConfigGroup grp(KSharedConfig::openConfig(), "testsettings");
+    KConfigGroup grp(KSharedConfig::openConfig(), QStringLiteral("testsettings"));
     info.writeConfig(grp);
 
-    ArchiveMailInfo restoreInfo(grp);
+    const ArchiveMailInfo restoreInfo(grp);
     QCOMPARE(info, restoreInfo);
 }
 
@@ -64,9 +68,13 @@ void ArchiveMailInfoTest::shouldCopyArchiveInfo()
     info.setLastDateSaved(QDate::currentDate());
     info.setMaximumArchiveCount(5);
     info.setEnabled(false);
+    info.setUseRange(true);
+    info.setRange({8, 7});
 
-    ArchiveMailInfo copyInfo(info);
+    const ArchiveMailInfo copyInfo(info);
     QCOMPARE(info, copyInfo);
 }
 
 QTEST_MAIN(ArchiveMailInfoTest)
+
+#include "moc_archivemailinfotest.cpp"
