@@ -8,7 +8,8 @@
 
 #include <QDialog>
 
-#include <KPIMTextEdit/PlainTextEditor>
+#include "mailfilteragentprivate_export.h"
+#include <TextCustomEditor/PlainTextEditor>
 
 class QCheckBox;
 class QSpinBox;
@@ -21,12 +22,12 @@ class QPushButton;
   The filter log dialog allows a continued observation of the
   filter log of MailFilterAgent.
 */
-namespace KPIMTextEdit
+namespace TextCustomEditor
 {
 class PlainTextEditorWidget;
 }
 
-class FilterLogTextEdit : public KPIMTextEdit::PlainTextEditor
+class FilterLogTextEdit : public TextCustomEditor::PlainTextEditor
 {
     Q_OBJECT
 public:
@@ -37,7 +38,7 @@ protected:
     void addExtraMenuEntry(QMenu *menu, QPoint pos) override;
 };
 
-class FilterLogDialog : public QDialog
+class MAILFILTERAGENTPRIVATE_EXPORT FilterLogDialog : public QDialog
 {
     Q_OBJECT
 
@@ -61,7 +62,7 @@ private:
     void readConfig();
     void writeConfig();
 
-    KPIMTextEdit::PlainTextEditorWidget *mTextEdit = nullptr;
+    TextCustomEditor::PlainTextEditorWidget *mTextEdit = nullptr;
     QCheckBox *mLogActiveBox = nullptr;
     QGroupBox *mLogDetailsBox = nullptr;
     QCheckBox *mLogPatternDescBox = nullptr;
