@@ -54,6 +54,7 @@ MailFilterAgent::MailFilterAgent(const QString &id)
     : Akonadi::AgentBase(id)
     , mProgressTimer(new QTimer(this))
 {
+    qRegisterMetaType<QList<qint64>>("QList<qint64>");
     Akonadi::AttributeFactory::registerAttribute<Akonadi::Pop3ResourceAttribute>();
     mMailFilterKernel = new DummyKernel(this);
     CommonKernel->registerKernelIf(mMailFilterKernel); // register KernelIf early, it is used by the Filter classes
@@ -282,6 +283,7 @@ QString MailFilterAgent::createUniqueName(const QString &nameTemplate)
 
 void MailFilterAgent::filterItems(const QList<qint64> &itemIds, int filterSet)
 {
+    qDebug() << " MailFilterAgent::filterItems ";
     Akonadi::Item::List items;
     items.reserve(itemIds.count());
     for (qint64 id : itemIds) {
@@ -329,6 +331,7 @@ void MailFilterAgent::applySpecificFiltersOnCollections(const QList<qint64> &col
 
 void MailFilterAgent::filterItem(qint64 item, int filterSet, const QString &resourceId)
 {
+    qDebug() << " MailFilterAgent::filterItem ";
     mFilterManager->filter(Akonadi::Item(item), static_cast<FilterManager::FilterSet>(filterSet), resourceId);
 }
 
@@ -376,7 +379,8 @@ void MailFilterAgent::emitProgressMessage(const QString &message)
 
 QString MailFilterAgent::printCollectionMonitored() const
 {
-    QString printDebugCollection;
+    QString printDebugCollection = QStringLiteral("Start print collection monitored\n");
+
     const Akonadi::Collection::List collections = changeRecorder()->collectionsMonitored();
     if (collections.isEmpty()) {
         printDebugCollection = QStringLiteral("No collection is monitored!");
@@ -389,6 +393,7 @@ QString MailFilterAgent::printCollectionMonitored() const
             printDebugCollection += QStringLiteral("Collection id: %1\n").arg(collection.id());
         }
     }
+    printDebugCollection += QStringLiteral("End print collection monitored\n");
     return printDebugCollection;
 }
 
