@@ -7,7 +7,7 @@
 #pragma once
 
 #include <PimCommon/PurposeMenuWidget>
-namespace KPIMTextEdit
+namespace TextCustomEditor
 {
 class PlainTextEditor;
 }
@@ -18,9 +18,9 @@ public:
     explicit MailfilterPurposeMenuWidget(QWidget *parentWidget, QObject *parent = nullptr);
     ~MailfilterPurposeMenuWidget() override;
 
-    Q_REQUIRED_RESULT QByteArray text() override;
-    void setEditorWidget(KPIMTextEdit::PlainTextEditor *editor);
+    [[nodiscard]] QByteArray text() override;
+    void setEditorWidget(TextCustomEditor::PlainTextEditor *editor);
 
 private:
-    KPIMTextEdit::PlainTextEditor *mEditor = nullptr;
+    TextCustomEditor::PlainTextEditor *mEditor = nullptr;
 };
