@@ -131,7 +131,6 @@ void SendLaterJob::sendDone()
                          QString(),
                          i18n("Message sent"),
                          QStringLiteral("kmail"),
-                         nullptr,
                          KNotification::CloseOnTimeout,
                          QStringLiteral("akonadi_sendlater_agent"));
     mManager->sendDone(mInfo);
@@ -144,9 +143,10 @@ void SendLaterJob::sendError(const QString &error, SendLaterManager::ErrorType t
                          QString(),
                          error,
                          QStringLiteral("kmail"),
-                         nullptr,
                          KNotification::CloseOnTimeout,
                          QStringLiteral("akonadi_sendlater_agent"));
     mManager->sendError(mInfo, type);
     deleteLater();
 }
+
+#include "moc_sendlaterjob.cpp"
