@@ -20,13 +20,9 @@
 
 int main(int argc, char **argv)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts, true);
     QApplication app(argc, argv);
-    KLocalizedString::setApplicationDomain("kmail-refresh-settings");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kmail-refresh-settings"));
     KCrash::initialize();
     KAboutData aboutData(QStringLiteral("kmail-refresh-settings"),
                          i18n("KMail Assistant for refreshing settings"),
