@@ -27,7 +27,7 @@ public:
     explicit MiscPageFolderTab(QWidget *parent = nullptr);
 
     void save() override;
-    Q_REQUIRED_RESULT QString helpAnchor() const;
+    [[nodiscard]] QString helpAnchor() const;
 
 private:
     void doLoadFromGlobalSettings() override;
@@ -50,19 +50,15 @@ private:
     void doLoadFromGlobalSettings() override;
 
 private:
-    MessageViewer::InvitationSettings *mInvitationUi = nullptr;
+    MessageViewer::InvitationSettings *const mInvitationUi;
 };
 
 class KMAIL_EXPORT MiscPage : public ConfigModuleWithTabs
 {
     Q_OBJECT
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit MiscPage(QWidget *parent = nullptr, const QVariantList &args = {});
-#else
-    explicit MiscPage(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
-#endif
-    Q_REQUIRED_RESULT QString helpAnchor() const override;
+    explicit MiscPage(QObject *parent, const KPluginMetaData &data);
+    [[nodiscard]] QString helpAnchor() const override;
 };
 
 class MiscPagePrintingTab : public ConfigModuleTab
@@ -77,7 +73,7 @@ private:
     void doLoadFromGlobalSettings() override;
 
 private:
-    MessageViewer::PrintingSettings *mPrintingUi = nullptr;
+    MessageViewer::PrintingSettings *const mPrintingUi;
 };
 
 #ifdef WITH_KUSERFEEDBACK
@@ -95,6 +91,6 @@ public:
 
 private:
     void doLoadFromGlobalSettings() override;
-    KUserFeedback::FeedbackConfigWidget *mUserFeedbackWidget = nullptr;
+    KUserFeedback::FeedbackConfigWidget *const mUserFeedbackWidget;
 };
 #endif
