@@ -15,9 +15,10 @@ ConfigurePluginPage::ConfigurePluginPage(QObject *parent, const KPluginMetaData
     , mConfigurePlugins(new PimCommon::ConfigurePluginsWidget(new ConfigurePluginsListWidget(widget()), widget()))
 {
     auto l = new QHBoxLayout(widget());
+    l->setContentsMargins({});
     l->addWidget(mConfigurePlugins);
 
-    connect(mConfigurePlugins, &PimCommon::ConfigurePluginsWidget::changed, this, &ConfigurePluginPage::slotConfigureChanged);
+    connect(mConfigurePlugins, &PimCommon::ConfigurePluginsWidget::changed, this, &ConfigurePluginPage::markAsChanged);
 }
 
 ConfigurePluginPage::~ConfigurePluginPage() = default;
@@ -42,9 +43,4 @@ void ConfigurePluginPage::load()
     mConfigurePlugins->doLoadFromGlobalSettings();
 }
 
-void ConfigurePluginPage::slotConfigureChanged()
-{
-    markAsChanged();
-}
-
 #include "moc_configurepluginpage.cpp"
