@@ -37,13 +37,8 @@ QString SecurityPage::helpAnchor() const
     return QStringLiteral("configure-security");
 }
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-SecurityPage::SecurityPage(QWidget *parent, const QVariantList &args)
-    : ConfigModuleWithTabs(parent, args)
-#else
-SecurityPage::SecurityPage(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : ConfigModuleWithTabs(parent, data, args)
-#endif
+SecurityPage::SecurityPage(QObject *parent, const KPluginMetaData &data)
+    : ConfigModuleWithTabs(parent, data)
 {
     //
     // "Reading" tab:
@@ -224,8 +219,8 @@ QString SecurityPageEncryptionTab::helpAnchor() const
 
 SecurityPageEncryptionTab::SecurityPageEncryptionTab(QWidget *parent)
     : ConfigModuleTab(parent)
+    , mWidget(new Ui::SecurityPageEncryptionTab)
 {
-    mWidget = new Ui::SecurityPageEncryptionTab;
     mWidget->setupUi(this);
     connect(mWidget->mAlwaysEncryptWhenSavingInDrafts, &QCheckBox::toggled, this, &SecurityPageEncryptionTab::slotEmitChanged);
     connect(mWidget->mStoreEncrypted, &QCheckBox::toggled, this, &SecurityPageEncryptionTab::slotEmitChanged);
@@ -338,8 +333,7 @@ void SecurityPageEncryptionTab::slotConfigureGnupg()
     QPointer<GpgSettingsDialog> dlg(new GpgSettingsDialog(this));
     dlg->setWindowTitle(i18nc("@title:window", "GnuPG Settings"));
     KPageWidgetItem *page = nullptr;
-    const auto plugin = KPluginMetaData::findPluginById((QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kcms/kleopatra")),
-                                                        QStringLiteral("kleopatra_config_gnupgsystem"));
+    const auto plugin = KPluginMetaData::findPluginById((QStringLiteral("pim6/kcms/kleopatra")), QStringLiteral("kleopatra_config_gnupgsystem"));
     if (plugin.isValid()) {
         page = dlg->addModule(plugin);
     }
@@ -700,14 +694,16 @@ void GpgSettingsDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(600, 400));
-    KConfigGroup group(KSharedConfig::openStateConfig(), myGpgSettingsDialogGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myGpgSettingsDialogGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void GpgSettingsDialog::saveConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myGpgSettingsDialogGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myGpgSettingsDialogGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
+
+#include "moc_configuresecuritypage.cpp"
