@@ -25,7 +25,7 @@ class SecurityPageGeneralTab : public ConfigModuleTab
     Q_OBJECT
 public:
     explicit SecurityPageGeneralTab(QWidget *parent = nullptr);
-    Q_REQUIRED_RESULT QString helpAnchor() const;
+    [[nodiscard]] QString helpAnchor() const;
 
     void save() override;
 
@@ -43,7 +43,7 @@ class SecurityPageMDNTab : public ConfigModuleTab
     Q_OBJECT
 public:
     explicit SecurityPageMDNTab(QWidget *parent = nullptr);
-    Q_REQUIRED_RESULT QString helpAnchor() const;
+    [[nodiscard]] QString helpAnchor() const;
 
     void save() override;
 
@@ -64,7 +64,7 @@ public:
     explicit SecurityPageEncryptionTab(QWidget *parent = nullptr);
     ~SecurityPageEncryptionTab() override;
 
-    Q_REQUIRED_RESULT QString helpAnchor() const;
+    [[nodiscard]] QString helpAnchor() const;
 
     void save() override;
 
@@ -75,7 +75,7 @@ private:
     void doLoadOther() override;
 
 private:
-    Ui::SecurityPageEncryptionTab *mWidget = nullptr;
+    Ui::SecurityPageEncryptionTab *const mWidget;
 };
 
 class SecurityPageSMimeTab : public ConfigModuleTab
@@ -85,7 +85,7 @@ public:
     explicit SecurityPageSMimeTab(QWidget *parent = nullptr);
     ~SecurityPageSMimeTab() override;
 
-    Q_REQUIRED_RESULT QString helpAnchor() const;
+    [[nodiscard]] QString helpAnchor() const;
 
     void save() override;
 
@@ -114,11 +114,6 @@ class KMAIL_EXPORT SecurityPage : public ConfigModuleWithTabs
 {
     Q_OBJECT
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit SecurityPage(QWidget *parent = nullptr, const QVariantList &args = {});
-#else
-    explicit SecurityPage(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
-#endif
-
-    Q_REQUIRED_RESULT QString helpAnchor() const override;
+    explicit SecurityPage(QObject *parent, const KPluginMetaData &data);
+    [[nodiscard]] QString helpAnchor() const override;
 };
