@@ -51,14 +51,16 @@ void SpellCheckerConfigDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(600, 400));
-    KConfigGroup group(KSharedConfig::openStateConfig(), "SpellCheckerConfigDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), QStringLiteral("SpellCheckerConfigDialog"));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void SpellCheckerConfigDialog::writeConfig()
 {
-    KConfigGroup notifyDialog(KMKernel::self()->config(), "SpellCheckerConfigDialog");
+    KConfigGroup notifyDialog(KMKernel::self()->config(), QStringLiteral("SpellCheckerConfigDialog"));
     KWindowConfig::saveWindowSize(windowHandle(), notifyDialog);
     notifyDialog.sync();
 }
+
+#include "moc_spellcheckerconfigdialog.cpp"
