@@ -41,7 +41,7 @@ AttachmentView::AttachmentView(MessageComposer::AttachmentModel *model, QWidget
     , mToolButton(new QToolButton(this))
     , mInfoAttachment(new QLabel(this))
     , mWidget(new QWidget())
-    , grp(KMKernel::self()->config()->group("AttachmentView"))
+    , grp(KMKernel::self()->config()->group(QStringLiteral("AttachmentView")))
 {
     auto lay = new QHBoxLayout(mWidget);
     lay->setContentsMargins({});
@@ -200,3 +200,5 @@ void AttachmentView::slotShowHideAttchementList(bool show)
         mToolButton->setToolTip(i18n("Show attachment list"));
     }
 }
+
+#include "moc_attachmentview.cpp"
