@@ -68,7 +68,7 @@ void KMComposerUpdateTemplateJob::setUoid(uint uoid)
     mUoid = uoid;
 }
 
-void KMComposerUpdateTemplateJob::setIdent(const KIdentityManagement::Identity &ident)
+void KMComposerUpdateTemplateJob::setIdent(const KIdentityManagementCore::Identity &ident)
 {
     mIdent = ident;
 }
@@ -77,3 +77,5 @@ void KMComposerUpdateTemplateJob::setCollection(const Akonadi::Collection &col)
 {
     mCollectionForNewMessage = col;
 }
+
+#include "moc_kmcomposerupdatetemplatejob.cpp"
