@@ -15,17 +15,18 @@ AttachmentMissingWarning::AttachmentMissingWarning(QWidget *parent)
     setVisible(false);
     setCloseButtonVisible(false);
     setMessageType(Information);
+    setPosition(KMessageWidget::Header);
     setText(i18n(
         "The message you have composed seems to refer to an attached file but you have not attached anything. Do you want to attach a file to your message?"));
     setWordWrap(true);
 
     auto action = new QAction(QIcon::fromTheme(QStringLiteral("mail-attachment")), i18n("&Attach file"), this);
-    action->setObjectName(QStringLiteral("attachfileaction"));
+    action->setObjectName(QLatin1StringView("attachfileaction"));
     connect(action, &QAction::triggered, this, &AttachmentMissingWarning::slotAttachFile);
     addAction(action);
 
     action = new QAction(QIcon::fromTheme(QStringLiteral("window-close")), i18n("&Remind me later"), this);
-    action->setObjectName(QStringLiteral("remindmelater"));
+    action->setObjectName(QLatin1StringView("remindmelater"));
     connect(action, &QAction::triggered, this, &AttachmentMissingWarning::explicitlyClosed);
     addAction(action);
 }
@@ -48,3 +49,5 @@ void AttachmentMissingWarning::explicitlyClosed()
     animatedHide();
     Q_EMIT explicitClosedMissingAttachment();
 }
+
+#include "moc_attachmentmissingwarning.cpp"
