@@ -11,6 +11,7 @@
 ExternalEditorWarning::ExternalEditorWarning(QWidget *parent)
     : KMessageWidget(parent)
 {
+    setPosition(KMessageWidget::Header);
     setVisible(false);
     setCloseButtonVisible(false);
     setMessageType(Information);
@@ -19,3 +20,5 @@ ExternalEditorWarning::ExternalEditorWarning(QWidget *parent)
 }
 
 ExternalEditorWarning::~ExternalEditorWarning() = default;
+
+#include "moc_externaleditorwarning.cpp"
