@@ -7,7 +7,7 @@ SPDX-License-Identifier: GPL-2.0-only
 #pragma once
 #include <Akonadi/Collection>
 #include <QAbstractListModel>
-#include <QVector>
+#include <QList>
 
 class CollectionSwitcherModel : public QAbstractListModel
 {
@@ -26,7 +26,7 @@ public:
         {
         }
 
-        Q_REQUIRED_RESULT bool operator==(const CollectionInfo &other) const;
+        [[nodiscard]] bool operator==(const CollectionInfo &other) const;
 
         Akonadi::Collection mNewCollection;
         QString mFullPath;
@@ -35,16 +35,16 @@ public:
     explicit CollectionSwitcherModel(QObject *parent = nullptr);
     ~CollectionSwitcherModel() override;
 
-    Q_REQUIRED_RESULT int rowCount(const QModelIndex &parent = QModelIndex()) const override;
-    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role) const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
 
     void addHistory(const Akonadi::Collection &currentCol, const QString &fullPath = {});
 
-    Q_REQUIRED_RESULT const Akonadi::Collection collection(int index);
+    [[nodiscard]] const Akonadi::Collection collection(int index);
 
 private:
-    QVector<CollectionInfo> mCollectionsInfo;
+    QList<CollectionInfo> mCollectionsInfo;
 };
 
 Q_DECLARE_METATYPE(CollectionSwitcherModel::CollectionInfo)
-Q_DECLARE_TYPEINFO(CollectionSwitcherModel::CollectionInfo, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(CollectionSwitcherModel::CollectionInfo, Q_RELOCATABLE_TYPE);
