@@ -12,9 +12,9 @@
 #include "ui_encodedimagepicker.h"
 
 #include <Akonadi/ContactSearchJob>
-#include <KIdentityManagement/Identity>
-#include <KIdentityManagement/IdentityManager>
-#include <KPIMTextEdit/PlainTextEditor>
+#include <KIdentityManagementCore/Identity>
+#include <KIdentityManagementCore/IdentityManager>
+#include <TextCustomEditor/PlainTextEditor>
 
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
@@ -40,7 +40,7 @@ EncodedImagePicker::EncodedImagePicker(QWidget *parent)
 
     connect(mUi->openImageButton, &QAbstractButton::clicked, this, &EncodedImagePicker::selectFile);
     connect(mUi->selectContactsButton, &QPushButton::released, this, &EncodedImagePicker::selectFromAddressBook);
-    connect(mUi->source->editor(), &KPIMTextEdit::PlainTextEditor::textChanged, this, &EncodedImagePicker::sourceChanged);
+    connect(mUi->source->editor(), &TextCustomEditor::PlainTextEditor::textChanged, this, &EncodedImagePicker::sourceChanged);
 }
 
 EncodedImagePicker::~EncodedImagePicker() = default;
@@ -112,7 +112,7 @@ void EncodedImagePicker::setFromFileDone(KJob *job)
 
 void EncodedImagePicker::selectFromAddressBook()
 {
-    using namespace KIdentityManagement;
+    using namespace KIdentityManagementCore;
 
     const IdentityManager manager(true);
     const Identity defaultIdentity = manager.defaultIdentity();
@@ -129,7 +129,7 @@ void EncodedImagePicker::selectFromAddressBookDone(KJob *job)
     const Akonadi::ContactSearchJob *searchJob = qobject_cast<Akonadi::ContactSearchJob *>(job);
 
     if (searchJob->contacts().isEmpty()) {
-        KMessageBox::information(this, i18n("You do not have your own contact defined in the address book."), i18n("No Picture"));
+        KMessageBox::information(this, i18n("You do not have your own contact defined in the address book."), i18nc("@title:window", "No Picture"));
         return;
     }
 
@@ -139,7 +139,7 @@ void EncodedImagePicker::selectFromAddressBookDone(KJob *job)
         const QImage photo = contact.photo().data();
 
         if (photo.isNull()) {
-            KMessageBox::information(this, i18n("No picture set for your address book entry."), i18n("No Picture"));
+            KMessageBox::information(this, i18n("No picture set for your address book entry."), i18nc("@title:window", "No Picture"));
         } else {
             Q_EMIT imageSelected(photo);
         }
@@ -147,9 +147,11 @@ void EncodedImagePicker::selectFromAddressBookDone(KJob *job)
         const QUrl url(contact.photo().url());
 
         if (url.isEmpty()) {
-            KMessageBox::information(this, i18n("No picture set for your address book entry."), i18n("No Picture"));
+            KMessageBox::information(this, i18n("No picture set for your address book entry."), i18nc("@title:window", "No Picture"));
         } else {
             setFromFile(url);
         }
     }
 }
+
+#include "moc_encodedimagepicker.cpp"
