@@ -104,9 +104,9 @@ void CreateNewContactJob::slotResourceCreationDone(KJob *job)
 
 void CreateNewContactJob::createContact()
 {
-    QPointer<ContactEditor::ContactEditorDialog> dlg = new ContactEditor::ContactEditorDialog(ContactEditor::ContactEditorDialog::CreateMode, mParentWidget);
-    connect(dlg.data(), &ContactEditor::ContactEditorDialog::contactStored, this, &CreateNewContactJob::contactStored);
-    connect(dlg.data(), &ContactEditor::ContactEditorDialog::error, this, &CreateNewContactJob::slotContactEditorError);
+    QPointer<Akonadi::ContactEditorDialog> dlg = new Akonadi::ContactEditorDialog(Akonadi::ContactEditorDialog::CreateMode, mParentWidget);
+    connect(dlg.data(), &Akonadi::ContactEditorDialog::contactStored, this, &CreateNewContactJob::contactStored);
+    connect(dlg.data(), &Akonadi::ContactEditorDialog::error, this, &CreateNewContactJob::slotContactEditorError);
     dlg->exec();
     delete dlg;
 }
@@ -119,5 +119,7 @@ void CreateNewContactJob::contactStored(const Akonadi::Item &item)
 
 void CreateNewContactJob::slotContactEditorError(const QString &error)
 {
-    KMessageBox::error(mParentWidget, i18n("Contact cannot be stored: %1", error), i18n("Failed to store contact"));
+    KMessageBox::error(mParentWidget, i18n("Contact cannot be stored: %1", error), i18nc("@title:window", "Failed to store contact"));
 }
+
+#include "moc_createnewcontactjob.cpp"
