@@ -1013,7 +1013,7 @@ KMCommand::Result KMRedirectCommand::execute()
         MessageComposer::MessageComposerSettings::self()->sendImmediate() ? MailCommon::RedirectDialog::SendNow : MailCommon::RedirectDialog::SendLater;
 
     QScopedPointer<MailCommon::RedirectDialog> dlg(new MailCommon::RedirectDialog(sendMode, parentWidget()));
-    dlg->setObjectName(QStringLiteral("redirect"));
+    dlg->setObjectName(QLatin1StringView("redirect"));
     if (dlg->exec() == QDialog::Rejected || !dlg) {
         return Failed;
     }
@@ -1755,9 +1755,8 @@ KMCommand::Result KMSaveAttachmentsCommand::execute()
     return Failed;
 }
 
-KMDeleteAttachmentsCommand::KMDeleteAttachmentsCommand(QWidget *parent, const Akonadi::Item::List &msgs, MessageViewer::Viewer *viewer)
+KMDeleteAttachmentsCommand::KMDeleteAttachmentsCommand(QWidget *parent, const Akonadi::Item::List &msgs)
     : KMCommand(parent, msgs)
-    , mViewer(viewer)
 {
     fetchScope().fetchFullPayload(true);
 }
