@@ -12,6 +12,8 @@
 #include <Libkdepim/ProgressStatusBarWidget>
 #include <Libkdepim/StatusbarProgressWidget>
 #include <PimCommon/BroadcastStatus>
+#include <PimCommon/NeedUpdateVersionUtils>
+#include <PimCommon/NeedUpdateVersionWidget>
 
 #include <KConfigGroup>
 #include <KToolBar>
@@ -19,6 +21,7 @@
 #include <QStatusBar>
 #include <QTimer>
 
+#include <KAboutData>
 #include <KConfig>
 #include <KConfigGui>
 #include <KEditToolBar>
@@ -30,6 +33,15 @@
 #include <QWindow>
 
 #include <QLabel>
+#include <QVBoxLayout>
+
+// signal handler for SIGINT & SIGTERM
+#ifdef Q_OS_UNIX
+#include <KSignalHandler>
+#include <signal.h>
+#include <unistd.h>
+#endif
+
 #include <chrono>
 
 using namespace std::chrono_literals;
@@ -39,17 +51,45 @@ KMMainWin::KMMainWin(QWidget *)
     , mMessageLabel(new QLabel(i18n("Starting...")))
 
 {
+#ifdef Q_OS_UNIX
+    /**
+     * Set up signal handler for SIGINT and SIGTERM
+     */
+    KSignalHandler::self()->watchSignal(SIGINT);
+    KSignalHandler::self()->watchSignal(SIGTERM);
+    connect(KSignalHandler::self(), &KSignalHandler::signalReceived, this, [this](int signal) {
+        if (signal == SIGINT || signal == SIGTERM) {
+            // Intercept console.
+            printf("Shutting down...\n");
+            slotQuit();
+        }
+    });
+#endif
     setObjectName(QLatin1StringView("kmail-mainwindow#"));
 
     resize(700, 500); // The default size
 
+    auto mainWidget = new QWidget(this);
+    auto mainWidgetLayout = new QVBoxLayout(mainWidget);
+    mainWidgetLayout->setContentsMargins({});
+    if (PimCommon::NeedUpdateVersionUtils::checkVersion()) {
+        const auto status = PimCommon::NeedUpdateVersionUtils::obsoleteVersionStatus(KAboutData::applicationData().version(), QDate::currentDate());
+        if (status != PimCommon::NeedUpdateVersionUtils::ObsoleteVersion::NotObsoleteYet) {
+            auto needUpdateVersionWidget = new PimCommon::NeedUpdateVersionWidget(this);
+            mainWidgetLayout->addWidget(needUpdateVersionWidget);
+            qDebug() << " KAboutData::applicationData().version() " << KAboutData::applicationData().version();
+            needUpdateVersionWidget->setObsoleteVersion(status);
+        }
+    }
+
     mKMMainWidget = new KMMainWidget(this, this, actionCollection());
+    mainWidgetLayout->addWidget(mKMMainWidget);
 
     // Don't initialize in constructor. We need this statusbar created
     // Bug 460289
     mProgressBar = new KPIM::ProgressStatusBarWidget(statusBar(), this);
     connect(mKMMainWidget, &KMMainWidget::recreateGui, this, &KMMainWin::slotUpdateGui);
-    setCentralWidget(mKMMainWidget);
+    setCentralWidget(mainWidget);
     setupStatusBar();
     if (!kmkernel->xmlGuiInstanceName().isEmpty()) {
         setComponentName(kmkernel->xmlGuiInstanceName(), i18n("KMail2"));
