@@ -14,6 +14,7 @@
 // widgets like a toolbar.
 
 #include "kmreadermainwin.h"
+#include "historyclosedreader/historyclosedreadermanager.h"
 #include "job/composenewmessagejob.h"
 #include "kmmainwidget.h"
 #include "kmreaderwin.h"
@@ -92,7 +93,7 @@ void KMReaderMainWin::initKMReaderMainWin()
     setupAccel();
     setupGUI(Keys | StatusBar | Create, QStringLiteral("kmreadermainwin.rc"));
     mMsgActions->setupForwardingActionsList(this);
-    applyMainWindowSettings(KMKernel::self()->config()->group("Separate Reader Window"));
+    applyMainWindowSettings(KMKernel::self()->config()->group(QStringLiteral("Separate Reader Window")));
     mZoomLabelIndicator = new ZoomLabelWidget(statusBar());
     statusBar()->addPermanentWidget(mZoomLabelIndicator);
     setZoomChanged(mReaderWin->viewer()->webViewZoomFactor());
@@ -112,8 +113,19 @@ void KMReaderMainWin::initKMReaderMainWin()
 
 KMReaderMainWin::~KMReaderMainWin()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(QStringLiteral("kmail2rc"))->group("Separate Reader Window"));
+    KConfigGroup grp(KSharedConfig::openConfig(QStringLiteral("kmail2rc"))->group(QStringLiteral("Separate Reader Window")));
     saveMainWindowSettings(grp);
+    if (mMsg.isValid()) {
+        HistoryClosedReaderInfo info;
+        info.setItem(mMsg.id());
+        KMime::Message::Ptr message = MessageComposer::Util::message(mMsg);
+        if (message) {
+            if (auto subject = message->subject(false)) {
+                info.setSubject(subject->asUnicodeString());
+            }
+        }
+        HistoryClosedReaderManager::self()->addInfo(std::move(info));
+    }
 }
 
 void KMReaderMainWin::setZoomChanged(qreal zoomFactor)
@@ -146,7 +158,9 @@ void KMReaderMainWin::showMessage(const QString &encoding, const Akonadi::Item &
     KMime::Message::Ptr message = MessageComposer::Util::message(msg);
     QString caption;
     if (message) {
-        caption = message->subject()->asUnicodeString();
+        if (auto subject = message->subject(false)) {
+            caption = subject->asUnicodeString();
+        }
     }
     if (mParentCollection.isValid()) {
         caption += QLatin1String(" - ");
@@ -200,7 +214,7 @@ void KMReaderMainWin::showPreviousMessage()
     updateButtons();
 }
 
-void KMReaderMainWin::showMessage(const QString &encoding, const QVector<KMime::Message::Ptr> &message)
+void KMReaderMainWin::showMessage(const QString &encoding, const QList<KMime::Message::Ptr> &message)
 {
     if (message.isEmpty()) {
         return;
@@ -226,8 +240,9 @@ void KMReaderMainWin::initializeMessage(const KMime::Message::Ptr &message)
     mMsgActions->setCurrentMessage(item);
 
     mReaderWin->setMessage(message);
-    setCaption(message->subject()->asUnicodeString());
-
+    if (auto subject = message->subject(false)) {
+        setCaption(subject->asUnicodeString());
+    }
     mTrashAction->setEnabled(false);
     mAkonadiStandardActionManager->setItems({mMsg});
     updateActions();
@@ -238,7 +253,7 @@ void KMReaderMainWin::showMessage(const QString &encoding, const KMime::Message:
     if (!message) {
         return;
     }
-    const QVector<KMime::Message::Ptr> lst{message};
+    const QList<KMime::Message::Ptr> lst{message};
     showMessage(encoding, lst);
 }
 
@@ -843,7 +858,7 @@ void KMReaderMainWin::showAndActivateWindow()
 
 void KMReaderMainWin::slotEditToolbars()
 {
-    KConfigGroup grp(KMKernel::self()->config(), "ReaderWindow");
+    KConfigGroup grp(KMKernel::self()->config(), QStringLiteral("ReaderWindow"));
     saveMainWindowSettings(grp);
     QPointer<KEditToolBar> dlg = new KEditToolBar(guiFactory(), this);
     connect(dlg.data(), &KEditToolBar::newToolBarConfig, this, &KMReaderMainWin::slotUpdateToolbars);
@@ -854,5 +869,7 @@ void KMReaderMainWin::slotEditToolbars()
 void KMReaderMainWin::slotUpdateToolbars()
 {
     createGUI(QStringLiteral("kmreadermainwin.rc"));
-    applyMainWindowSettings(KConfigGroup(KMKernel::self()->config(), "ReaderWindow"));
+    applyMainWindowSettings(KConfigGroup(KMKernel::self()->config(), QStringLiteral("ReaderWindow")));
 }
+
+#include "moc_kmreadermainwin.cpp"
