@@ -46,7 +46,7 @@ public:
 
     void setUseFixedFont(bool useFixedFont);
 
-    MessageViewer::Viewer *viewer() const;
+    [[nodiscard]] MessageViewer::Viewer *viewer() const;
     /**
      * take ownership of and show @p msg
      *
@@ -61,7 +61,7 @@ public:
      */
     void showMessage(const QString &encoding, const Akonadi::Item &msg, const Akonadi::Collection &parentCollection = Akonadi::Collection());
 
-    void showMessage(const QString &encoding, const QVector<KMime::Message::Ptr> &message);
+    void showMessage(const QString &encoding, const QList<KMime::Message::Ptr> &message);
     void showMessage(const QString &encoding, const KMime::Message::Ptr &message);
     void showMessagePopup(const Akonadi::Item &msg,
                           const QUrl &aUrl,
@@ -99,7 +99,7 @@ private:
     void slotShowMessageStatusBar(const QString &msg);
 
     void copyOrMoveItem(const Akonadi::Collection &collection, bool move);
-    Q_REQUIRED_RESULT Akonadi::Collection parentCollection() const;
+    [[nodiscard]] Akonadi::Collection parentCollection() const;
     void initKMReaderMainWin();
     void setupAccel();
     QAction *copyActionMenu(QMenu *menu);
@@ -117,7 +117,7 @@ private:
     void initializeAkonadiStandardAction();
     void slotMarkMailAs();
 
-    QVector<KMime::Message::Ptr> mListMessage;
+    QList<KMime::Message::Ptr> mListMessage;
     int mCurrentMessageIndex = 0;
     Akonadi::Collection mParentCollection;
     Akonadi::Item mMsg;
