@@ -29,7 +29,7 @@ public:
     }
 
     void loadCommandLineOptions(QCommandLineParser *parser) override;
-    Q_REQUIRED_RESULT int activate(const QStringList &args, const QString &workingDir) override;
+    [[nodiscard]] int activate(const QStringList &args, const QString &workingDir) override;
 };
 
 class KMailPlugin : public KontactInterface::Plugin
@@ -40,12 +40,12 @@ public:
     KMailPlugin(KontactInterface::Core *core, const KPluginMetaData &data, const QVariantList &);
     ~KMailPlugin() override;
 
-    Q_REQUIRED_RESULT bool isRunningStandalone() const override;
-    Q_REQUIRED_RESULT KontactInterface::Summary *createSummaryWidget(QWidget *parent) override;
-    Q_REQUIRED_RESULT int weight() const override;
+    [[nodiscard]] bool isRunningStandalone() const override;
+    [[nodiscard]] KontactInterface::Summary *createSummaryWidget(QWidget *parent) override;
+    [[nodiscard]] int weight() const override;
 
-    Q_REQUIRED_RESULT QStringList invisibleToolbarActions() const override;
-    Q_REQUIRED_RESULT bool queryClose() const override;
+    [[nodiscard]] QStringList invisibleToolbarActions() const override;
+    [[nodiscard]] bool queryClose() const override;
 
     void shortcutChanged() override;
 
@@ -53,7 +53,7 @@ protected:
     KParts::Part *createPart() override;
     void openComposer(const QUrl &attach = QUrl());
     void openComposer(const QString &to);
-    Q_REQUIRED_RESULT bool canDecodeMimeData(const QMimeData *) const override;
+    [[nodiscard]] bool canDecodeMimeData(const QMimeData *) const override;
     void processDropEvent(QDropEvent *) override;
 
 protected Q_SLOTS:
