@@ -12,7 +12,7 @@ KMailPluginInterface::KMailPluginInterface(QObject *parent)
     : PimCommon::PluginInterface(parent)
 {
     setPluginName(QStringLiteral("kmail"));
-    setPluginDirectory(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kmail/mainview"));
+    setPluginDirectory(QStringLiteral("pim6/kmail/mainview"));
 }
 
 KMailPluginInterface::~KMailPluginInterface() = default;
@@ -54,3 +54,5 @@ bool KMailPluginInterface::initializeInterfaceRequires(PimCommon::AbstractGeneri
     }
     return true;
 }
+
+#include "moc_kmailplugininterface.cpp"
