@@ -16,7 +16,6 @@
 #include "kmkernel.h"
 #include "kmmainwidget.h"
 #include "kmsearchmessagemodel.h"
-#include "messagecore/stringutil.h"
 #include "searchdescriptionattribute.h"
 #include "searchpatternwarning.h"
 #include <MailCommon/FolderRequester>
@@ -25,6 +24,7 @@
 #include <MailCommon/SearchPatternEdit>
 #include <PimCommon/PimUtil>
 #include <PimCommonAkonadi/SelectMultiCollectionDialog>
+#include <TextUtils/ConvertText>
 
 #include "kmail_debug.h"
 #include <Akonadi/CachePolicy>
@@ -422,7 +422,7 @@ void SearchWindow::doSearch()
 
     mUi.mSearchFolderEdt->setEnabled(false);
 
-    QVector<Akonadi::Collection> searchCollections;
+    QList<Akonadi::Collection> searchCollections;
     bool recursive = false;
     if (mUi.mChkbxSpecificFolders->isChecked()) {
         const Akonadi::Collection col = mUi.mCbxFolders->collection();
@@ -482,14 +482,14 @@ void SearchWindow::doSearch()
     qCDebug(KMAIL_LOG) << mQuery.toJSON();
     mUi.mSearchFolderOpenBtn->setEnabled(true);
 
-    const QVector<qint64> unindexedCollections = checkIncompleteIndex(searchCollections, recursive);
+    const QList<qint64> unindexedCollections = checkIncompleteIndex(searchCollections, recursive);
     if (!unindexedCollections.isEmpty()) {
         IncompleteIndexDialog dlg(unindexedCollections);
         dlg.exec();
     }
 
     auto config = KConfig(QStringLiteral("akonadi_indexing_agent"));
-    KConfigGroup cfg = config.group("General");
+    KConfigGroup cfg = config.group(QStringLiteral("General"));
     const bool respectDiacriticAndAccents = cfg.readEntry("respectDiacriticAndAccents", true);
 
     if (mFolder.isValid()) {
@@ -504,7 +504,7 @@ void SearchWindow::doSearch()
         mSearchJob = new Akonadi::CollectionModifyJob(mFolder, this);
     } else {
         const QString searchString =
-            respectDiacriticAndAccents ? mUi.mSearchFolderEdt->text() : MessageCore::StringUtil::normalize(mUi.mSearchFolderEdt->text());
+            respectDiacriticAndAccents ? mUi.mSearchFolderEdt->text() : TextUtils::ConvertText::normalize(mUi.mSearchFolderEdt->text());
         qCDebug(KMAIL_LOG) << " create new folder " << searchString;
         auto searchJob = new Akonadi::SearchCreateJob(searchString, mQuery, this);
         searchJob->setSearchMimeTypes(QStringList() << QStringLiteral("message/rfc822"));
@@ -884,9 +884,9 @@ void SearchWindow::slotJumpToFolder()
     }
 }
 
-QVector<qint64> SearchWindow::checkIncompleteIndex(const Akonadi::Collection::List &searchCols, bool recursive)
+QList<qint64> SearchWindow::checkIncompleteIndex(const Akonadi::Collection::List &searchCols, bool recursive)
 {
-    QVector<qint64> results;
+    QList<qint64> results;
     Akonadi::Collection::List cols;
     if (recursive) {
         cols = searchCollectionsRecursive(searchCols);
@@ -953,3 +953,5 @@ Akonadi::Collection::List SearchWindow::searchCollectionsRecursive(const Akonadi
 
     return result;
 }
+
+#include "moc_searchwindow.cpp"
