@@ -121,7 +121,7 @@ void TagActionManager::onSignalMapped(const QString &tag)
     Q_EMIT tagActionTriggered(Akonadi::Tag(tag.toLongLong()));
 }
 
-void TagActionManager::createTagActions(const QVector<MailCommon::Tag::Ptr> &tags)
+void TagActionManager::createTagActions(const QList<MailCommon::Tag::Ptr> &tags)
 {
     clearActions();
 
@@ -254,3 +254,5 @@ QList<qint64> TagActionManager::checkedTags() const
     }
     return checked;
 }
+
+#include "moc_tagactionmanager.cpp"
