@@ -50,10 +50,12 @@ void KActionMenuTransport::updateTransportMenu()
 
 void KActionMenuTransport::slotSelectTransport(QAction *act)
 {
-    const QVector<int> availTransports = MailTransport::TransportManager::self()->transportIds();
+    const QList<int> availTransports = MailTransport::TransportManager::self()->transportIds();
     const int transportId = act->data().toInt();
     if (availTransports.contains(transportId)) {
         MailTransport::Transport *transport = MailTransport::TransportManager::self()->transportById(transportId);
         Q_EMIT transportSelected(transport);
     }
 }
+
+#include "moc_kactionmenutransport.cpp"
